---
title: <span class="badge object-type-scalar"></span> DatetimeUS
---
# <span class="badge object-type-scalar"></span> DatetimeUS

Date & time: Datetime US

## Definition

```python
# Date & time: Datetime US
DatetimeUS: typing.Literal["dateTimeAsUS"] = "dateTimeAsUS"
```
